```{include} ../../README.md
:relative-images:
```

```{toctree}
:caption: 'Contents:'
:maxdepth: 2
#module1
#module2
#api/modules
# Remove or comment out the following line if api/modules does not exist
# api/modules
```


# Indices and tables

- {ref}`genindex`
- {ref}`modindex`
- {ref}`search`


